@@ -336,6 +336,10 @@ ExceptionDays::ExceptionDays()
 
 ExceptionDays::~ExceptionDays()
 {
+  std::cout << "ExceptionDays: DELETE" << std::endl;
+  DaysList_t::iterator it;
+  for (it = daysList_m.begin(); it != daysList_m.end(); it++)
+    delete (*it);
 }
 
 ExceptionDays* ExceptionDays::instance()
